%define Werror_cflags %nil
# Modules always contain just 32-bit code
%define _libdir %{_exec_prefix}/lib
%ifarch	x86_64
# 64bit intel machines use 32bit boot loader
# (We cannot just redefine _target_cpu, as we'd get i386.rpm packages)
%global _target_platform i386-%{_vendor}-%{_target_os}%{?_gnu}
%global efi_arch x86_64-efi
%else
%global efi_arch i386-efi
%endif

%global pc_arch i386-pc

Name:		grub2
Version:	2.02
Release:	%mkrel 3
Summary:	Boot-loader with support for Linux, Multiboot and more
Group:		System/Kernel and hardware
License:	GPLv3+ and GPLv2
URL:		http://www.gnu.org/software/grub/
Source0:	ftp://ftp.gnu.org/gnu/grub/grub-%{version}.tar.xz
Source1:	90_persistent
Source2:	grub.default.pclinuxos
Source5:	grub2.filter
Source6:	grub2.script
Source8:	mkfonts
Source9:	unicode.pf2
Source16:	93_memtest

BuildRequires:	flex
BuildRequires:	bison
BuildRequires:	ruby
BuildRequires:	binutils
BuildRequires:	glibc-static-devel
BuildRequires:	ncurses-devel
BuildRequires:	liblzo-devel
BuildRequires:	freetype2-devel
BuildRequires:	libusb-devel
BuildRequires:	help2man
BuildRequires:	texinfo
BuildRequires:	libdevmapper-devel
BuildRequires:	fuse-devel
BuildRequires:	autogen

Requires:	os-prober
Provides:	bootloader
Provides:	grub2bootloader
Requires:	grub2-theme-pclinuxos

%description
This is the second version of the GRUB (Grand Unified Boot-loader), a highly
configurable and customizable boot-loader with modular architecture.
It supports a wide range of kernel formats, file systems, computer
architectures and hardware devices. It may be safely installed alongside
legacy grub.

%package efi
Summary:	Boot-loader with support for EFI
Group:		System/Kernel and hardware
Requires:	%{name}


%description efi
This is the second version of the GRUB (Grand Unified Boot-loader), a highly
configurable and customizable boot-loader with modular architecture.
It supports a wide range of kernel formats, file systems, computer
architectures and hardware devices. It may be safely installed alongside
legacy grub.  This subpackage provides support for EFI systems.

%prep
%setup -q -n grub-%{version}


%build
cd ..
pushd grub-%{version}/grub-%{version}
./autogen.sh
%configure2_5x TARGET_LDFLAGS=-static			\
	  --with-platform=pc				\
	  --enable-grub-emu-usb				\
	  --disable-werror				\
	  --enable-grub-mkfont				\
	  --program-transform-name=s,grub,%{name},	\
	  --with-bootdir=/boot				\
	  --with-grubdir=/%{name}			\
	  CFLAGS=""
%make
popd

pushd grub-%{version}/grub-efi-%{version}
./autogen.sh
%configure2_5x TARGET_LDFLAGS=-static			\
	  --with-platform=efi				\
%ifarch x86_64
	  --target=x86_64				\
%endif
	  --enable-grub-emu-usb				\
	  --disable-werror				\
	  --enable-grub-mkfont				\
	  --program-transform-name=s,grub,%{name},	\
	  --with-bootdir=/boot				\
	  --with-grubdir=/%{name}			\
	  CFLAGS=""
%make
popd

%install
rm -rf %buildroot
cd ..
pushd grub-%{version}/grub-efi-%{version}
%makeinstall_std
popd

pushd grub-%{version}/grub-%{version}
%makeinstall_std

# (bor) grub.info is harcoded in sources
mv %{buildroot}%{_infodir}/grub.info %{buildroot}%{_infodir}/%{name}.info

# Script that makes part of grub.cfg persist across updates
install -m 755 %{SOURCE1} %{buildroot}%{_sysconfdir}/grub.d

# Memtest
install -m 755 %{SOURCE16} %{buildroot}%{_sysconfdir}/grub.d

# Font
install -d %{buildroot}/boot/%{name}/fonts
install -D %{SOURCE9} %{buildroot}/boot/%{name}/fonts

install -d %{buildroot}/boot/%{name}/themes

# Ghost config files
install -d %{buildroot}/boot/%{name}
touch %{buildroot}/boot/%{name}/grub.cfg

# Workaround for RHL Bug 817187
install -d %{buildroot}%{_datadir}/locale/en/LC_MESSAGES
ln -s %{_datadir}/locale/en@quot/LC_MESSAGES/grub.mo %{buildroot}%{_datadir}/locale/en/LC_MESSAGES/grub.mo

cat > %{buildroot}/boot/%{name}/custom.cfg <<EOF
# Set non-graphical text/background colours
set menu_color_normal=cyan/blue
set menu_color_highlight=white/blue

# Add any extra custom menu entries in here:

EOF

# Provide 'update-grub' and update-grub2 symlink for *buntu exiles ;) 
cat > %{buildroot}%{_bindir}/update-grub <<EOF
#!/bin/sh
su --login root -c "/usr/sbin/grub2-mkconfig -o /boot/grub2/grub.cfg"

EOF
chmod +x %{buildroot}%{_bindir}/update-grub
ln -s %{_bindir}/update-grub %{buildroot}%{_bindir}/update-grub2

# Filetriggers
install -d %{buildroot}/%{_filetriggers_dir}
install -D %{SOURCE5} %{buildroot}/%{_filetriggers_dir}/%{name}.filter
install -D %{SOURCE6} %{buildroot}/%{_filetriggers_dir}/%{name}.script

# Defaults
install -m 644 -D %{SOURCE2} %{buildroot}%{_sysconfdir}/default/grub

# Remove "GNU/Linux" in menu selections
sed -i 's/ GNU\/Linux//' %{buildroot}%{_sysconfdir}/grub.d/10_linux

#remove startfield theme
rm -rf %{buildroot}/%{_datadir}/grub/themes/starfield


%find_lang grub

popd

%post
# On update re-install grub2 to where it was installed by drakboot if possible,
# otherwise next boot may fail due to mismatched boot code.

if [ $1 -eq 2 ]; then
   if [ -f /boot/grub2/install.sh -a -x /usr/sbin/detectloader ]; then
 	LOADER=$(/usr/sbin/detectloader)
 	[ "$LOADER" = "GRUB2" ] && /boot/grub2/install.sh
   fi
fi


%post efi
# On update re-install grub2 to where it was installed by drakboot if possible,
# otherwise next boot may fail due to mismatched boot code.

if [ $1 -eq 2 ]; then
   if [ -f /boot/grub2/install.sh -a -x /usr/sbin/detectloader ]; then
 	LOADER=$(/usr/sbin/detectloader)
 	[ "$LOADER" = "GRUB2" ] && /boot/grub2/install.sh
   fi
fi


%preun
exec > /var/log/%{name}_preun.log 2>&1
# Only if uninstalling
if [ $1 -eq 0 ]; then
rm -rf /boot/%{name}/%{pc_arch}
rm -rf /boot/%{name}/locale
fi

%preun efi
exec > /var/log/%{name}_preun.log 2>&1
# Only if uninstalling
if [ $1 -eq 0 ]; then
rm -rf /boot/%{name}/%{efi_arch}
rm -rf /boot/%{name}/locale
fi

%triggerpostun efi -- %{name}-efi < 2.02
%{name}-mkconfig -o /boot/%{name}/grub.cfg


%files
%defattr(-,root,root,-)
%{_infodir}/*
%dir %{_libdir}/grub
%dir %{_libdir}/grub/i386-pc
%dir /boot/%{name}
%dir /boot/%{name}/fonts
%dir /boot/%{name}/themes
%{_libdir}/grub/i386-pc/*
%{_bindir}/%{name}-*
%{_bindir}/update-grub
%{_bindir}/update-grub2
%{_sbindir}/%{name}-*
%{_sysconfdir}/bash_completion.d/grub
%{_sysconfdir}/grub.d/README
%{_sysconfdir}/grub.d/00_header
%{_sysconfdir}/grub.d/10_linux
%{_sysconfdir}/grub.d/20_linux_xen
%{_sysconfdir}/grub.d/20_ppc_terminfo
%{_sysconfdir}/grub.d/93_memtest
%{_sysconfdir}/grub.d/30_os-prober
%{_sysconfdir}/grub.d/90_persistent
%config(noreplace) %{_sysconfdir}/grub.d/40_custom
%config(noreplace) %{_sysconfdir}/grub.d/41_custom
%{_datadir}/grub
%config(noreplace) /boot/%{name}/grub.cfg
%config(noreplace) /boot/%{name}/custom.cfg
%{_mandir}/man1/%{name}-*.1*
%{_mandir}/man8/%{name}-*.8*
%{_filetriggers_dir}/%{name}.filter
%{_filetriggers_dir}/%{name}.script

#dont replace this on update
%config(noreplace) %{_sysconfdir}/default/grub

#goes in theme package
%exclude /boot/grub2/fonts/unicode.pf2
%{_datadir}/locale


%files efi
%defattr(-,root,root,-)
%dir %{_libdir}/grub
%dir %{_libdir}/grub/%{efi_arch}
%{_libdir}/grub/%{efi_arch}/*

%changelog
* Mon Apr 27 2015 TerryN <terryn94 at gmail.com> 2.02-3pclos2015
- grub2/grub2-efi no longer conflict

* Fri Apr 10 2015 bb <bb> 2.02-2pclos2015
- update postscripts
- add theme dependency

* Thu Apr 02 2015 bb <bb> 2.02-1pclos2015
- update from git with patches applied

* Sat Jun 21 2014 bb <bb> 2.00-3pclos2014
- change /etc/default/grub so plymouth works on pclos

* Fri Jun 20 2014 bb <bb> 2.00-2pclos2014
- fix post script for pclos

* Fri May 23 2014 bb <bb> 2.00-1pclos2014
- import into pclos
